from setuptools import setup

setup(name='USEofCS',
      version='0.1.5',
      author='zef',
      author_email='zef.report.pypi@mail.ru',
      descripdion='Python module to help you write your USE in computer science',
      long_descripdion='Python module to help you write your USE in computer science',
      packages=['USEofCS'])
